==> 0.0.6.tar.gz: lib/src/restoqueGenericDao.dart <==
class RestoqueGenericDao {
  String restoqueGenericDao = "";
  RestoqueGenericDao() {
    restoqueGenericDao +=
        "var _Store  = StoreRef<String, dynamic>(\"@TableName\");";
    restoqueGenericDao += "@element instance;";
    restoqueGenericDao += "_\$@element(@element _instance)";
    restoqueGenericDao += "{";
    restoqueGenericDao += "  instance = _instance;";
    restoqueGenericDao += "}";
    restoqueGenericDao +=
        "Future<DatabaseClient> get _db async => await AppDatabase.instance.database;";

    restoqueGenericDao += "class _@element";
    restoqueGenericDao += "{";

    restoqueGenericDao += "  Future Upsert() async {";
    restoqueGenericDao += "    final db = await _db;";
    restoqueGenericDao += "    var sJson = json.encode(this);";
    restoqueGenericDao += "    await _Store.record(@Key).put(db, sJson);";

    restoqueGenericDao += "  }";

    restoqueGenericDao += "  Future UpsertAll(List<@element> toInsert) async";
    restoqueGenericDao += "  {";
    restoqueGenericDao += "    await toInsert.forEach((row) async";
    restoqueGenericDao += "    {";
    restoqueGenericDao += "      await row.Upsert();";
    restoqueGenericDao += "    });";
    restoqueGenericDao += "  }";

    restoqueGenericDao += "  Future Delete() async {";
    restoqueGenericDao +=
        "    final finder = Finder(filter: Filter.byKey(@Key));";
    restoqueGenericDao += "    await _Store.delete(";
    restoqueGenericDao += "      await _db,";
    restoqueGenericDao += "      finder: finder,";
    restoqueGenericDao += "    );";
    restoqueGenericDao += "  }";

    restoqueGenericDao += "  Future<List<@element>> GetAll() async {";
    restoqueGenericDao += "    final db = await _db;";
    restoqueGenericDao += "    final recordSnapshots = await _Store.find(db);";
    restoqueGenericDao += "    var list = recordSnapshots.map((snapshot) {";
    restoqueGenericDao +=
        "      final object = @element.fromJson(json.decode(snapshot.value));";
    restoqueGenericDao += "      return object;";
    restoqueGenericDao += "    }).toList();";
    restoqueGenericDao += "    return list;";
    restoqueGenericDao += "  }";

    restoqueGenericDao += "  Future<@element> GetByKey(String key) async {";
    restoqueGenericDao += "    final db = await _db;";
    restoqueGenericDao += "    var result = await _Store.record(key).get(db);";
    restoqueGenericDao +=
        "    return result == null ? null : @element.fromJson(json.decode(result));";
    restoqueGenericDao += "  }";

    restoqueGenericDao += "  @FilterFunctions";

    restoqueGenericDao += "}";
    restoqueGenericDao += "@toJson";
    restoqueGenericDao += " @fromJson";
  }
}

==> 0.1.0.tar.gz: lib/src/restoqueGenericDao.dart <==
class RestoqueGenericDao {
  String restoqueGenericDao = "";
  RestoqueGenericDao() {
    restoqueGenericDao +=
        "var _Store  = StoreRef<String, dynamic>(\"@TableName\");";
    restoqueGenericDao += "@element instance;";
    restoqueGenericDao += "_\$@element(@element _instance)";
    restoqueGenericDao += "{";
    restoqueGenericDao += "  instance = _instance;";
    restoqueGenericDao += "}";
    restoqueGenericDao +=
        "Future<DatabaseClient> get _db async => await AppDatabase.instance.database;";

    restoqueGenericDao += "class _@element";
    restoqueGenericDao += "{";

    restoqueGenericDao += "  Future Upsert() async {";
    restoqueGenericDao += "    final db = await _db;";
    restoqueGenericDao += "    var sJson = json.encode(this);";
    restoqueGenericDao += "    await _Store.record(@Key).put(db, sJson);";

    restoqueGenericDao += "  }";

    restoqueGenericDao += "  Future UpsertAll(List<@element> toInsert) async";
    restoqueGenericDao += "  {";
    restoqueGenericDao += "    await Future.forEach(toInsert, (row) async {";
    restoqueGenericDao += "      await (row as @element).Upsert();";
    restoqueGenericDao += "    });";
    restoqueGenericDao += "  }";

    restoqueGenericDao += "  Future Delete() async {";
    restoqueGenericDao +=
        "    final finder = Finder(filter: Filter.byKey(@Key));";
    restoqueGenericDao += "    await _Store.delete(";
    restoqueGenericDao += "      await _db,";
    restoqueGenericDao += "      finder: finder,";
    restoqueGenericDao += "    );";
    restoqueGenericDao += "  }";

    restoqueGenericDao += "  Future<List<@element>> GetAll() async {";
    restoqueGenericDao += "    final db = await _db;";
    restoqueGenericDao += "    final recordSnapshots = await _Store.find(db);";
    restoqueGenericDao += "    var list = recordSnapshots.map((snapshot) {";
    restoqueGenericDao +=
        "      final object = @element.fromJson(json.decode(snapshot.value));";
    restoqueGenericDao += "      return object;";
    restoqueGenericDao += "    }).toList();";
    restoqueGenericDao += "    return list;";
    restoqueGenericDao += "  }";

    restoqueGenericDao += "  Future<@element> GetByKey(String key) async {";
    restoqueGenericDao += "    final db = await _db;";
    restoqueGenericDao += "    var result = await _Store.record(key).get(db);";
    restoqueGenericDao +=
        "    return result == null ? null : @element.fromJson(json.decode(result));";
    restoqueGenericDao += "  }";

    restoqueGenericDao += "  @FilterFunctions";

    restoqueGenericDao += "}";
    restoqueGenericDao += "@toJson";
    restoqueGenericDao += " @fromJson";
  }
}
